From 1c83af88377b73ff0982dce164f3a7124acf49ea Mon Sep 17 00:00:00 2001
From: frdel <38891707+frdel@users.noreply.github.com>
Date: Sat, 31 Jan 2026 17:47:09 +0100
Subject: [PATCH] welcome screen polishing.
---
.../extensions/banners/_20_missing_api_key.py | 6 +-
webui/components/sidebar/chats/chats-store.js | 17 +-
webui/components/welcome/welcome-screen.html | 206 ++++++++++--------
webui/components/welcome/welcome-store.js | 7 +
webui/index.js | 19 +-
5 files changed, 134 insertions(+), 121 deletions(-)
diff --git a/python/extensions/banners/_20_missing_api_key.py b/python/extensions/banners/_20_missing_api_key.py
index 9d31a5b50..672f8d3bb 100644
--- a/python/extensions/banners/_20_missing_api_key.py
+++ b/python/extensions/banners/_20_missing_api_key.py
@@ -54,9 +54,9 @@ class MissingApiKeyCheck(Extension):
"id": "missing-api-key",
"type": "error",
"priority": 100,
- "title": "Missing API Key",
- "html": f"""No API key configured for: {model_list}.
- Agent Zero will not be able to function properly.
+ "title": "Missing LLM API Key for current settings",
+ "html": f"""No API key configured for: {model_list}.
+ Agent Zero will not be able to function properly unless you provide an API key or change your settings.
Add your API key in Settings → External Services → API Keys.""",
"dismissible": False,
diff --git a/webui/components/welcome/welcome-screen.html b/webui/components/welcome/welcome-screen.html
index a5252eb9e..de3d5d84a 100644
--- a/webui/components/welcome/welcome-screen.html
+++ b/webui/components/welcome/welcome-screen.html
@@ -10,88 +10,71 @@
- Start a new conversation or explore the features below. -
- - -- Start a new conversation -
-- Manage your projects -
-- Open Memory Dashboard -
-- Configure Agent Zero -
-- Learn more about Agent Zero -
-- View source code and documentation -
-
diff --git a/webui/components/sidebar/chats/chats-store.js b/webui/components/sidebar/chats/chats-store.js
index a2f1cdcfa..ab72e791d 100644
--- a/webui/components/sidebar/chats/chats-store.js
+++ b/webui/components/sidebar/chats/chats-store.js
@@ -27,11 +27,10 @@ const model = {
},
init() {
- // Initialize from localStorage
- const lastSelectedChat = localStorage.getItem("lastSelectedChat");
+ // Initialize from sessionStorage
+ const lastSelectedChat = sessionStorage.getItem("lastSelectedChat");
if (lastSelectedChat) {
this.selectChat(lastSelectedChat);
- // this.selected = lastSelectedChat;
}
},
@@ -260,11 +259,15 @@ const model = {
// Set selected context
setSelected(contextId) {
- this.selected = contextId;
- this.selectedContext = this.contexts.find((ctx) => ctx.id === contextId);
+ this.selected = contextId || "";
+ this.selectedContext = this.contexts.find((ctx) => ctx.id === this.selected);
// if not found in contexts, try to find in tasks < not nice, will need refactor later
- if(!this.selectedContext) this.selectedContext = tasksStore.tasks.find((ctx) => ctx.id === contextId);
- localStorage.setItem("lastSelectedChat", contextId);
+ if(!this.selectedContext) this.selectedContext = tasksStore.tasks.find((ctx) => ctx.id === this.selected);
+ if (this.selected) {
+ sessionStorage.setItem("lastSelectedChat", this.selected);
+ } else {
+ sessionStorage.removeItem("lastSelectedChat");
+ }
},
// Restart the backend